/***************************************************************************
 *   Copyright (C) 2005 by Andreas Silberstorff   *
 *   ml@andreas-silberstorff.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 *   In addition, as a special exception, the copyright holders give       *
 *   permission to link the code of this program with any edition of       *
 *   the Qt library by Trolltech AS, Norway (or with modified versions     *
 *   of Qt that use the same license as Qt), and distribute linked         *
 *   combinations including the two.  You must obey the GNU General        *
 *   Public License in all respects for all of the code used other than    *
 *   Qt.  If you modify this file, you may extend this exception to        *
 *   your version of the file, but you are not obligated to do so.  If     *
 *   you do not wish to do so, delete this exception statement from        *
 *   your version.                                                         *
 ***************************************************************************/

#include "kalvaview.h"
#include "settings.h"
#include "kalva_channellist.h"
#include "kalva_player.h"
#include "kalva_recorder.h"

#include <klocale.h>
#include <qlabel.h>
#include <qsplitter.h>
#include <qtabwidget.h>
#include <qlayout.h>
#include <qsizepolicy.h>

KalvaView::KalvaView(QWidget *parent)
    : DCOPObject( "DCOP_kalva" ),
      QWidget(parent)
{
    setName( "kalvaview" );

    m_splitter    = new QSplitter( QSplitter::Horizontal, this, "splitter" );
    m_channellist = new KalvaChannellist( m_splitter, "channellist" );
    m_tabWidget   = new QTabWidget( m_splitter, "tabWidget" );
    m_tabPlayer   = new QWidget( m_tabWidget, "tabPlayer" );
    m_tabWidget->insertTab( m_tabPlayer, QString::fromLatin1(i18n("play")) );
    m_player      = new KalvaPlayer( m_tabPlayer, "player" );
    m_tabRecorder = new QWidget( m_tabWidget, "tabRecorder" );
    m_tabWidget->insertTab( m_tabRecorder, QString::fromLatin1(i18n("record")) );
    m_recorder    = new KalvaRecorder( m_tabRecorder, "recorder" );

    m_channellist->resize(m_channellist->minimumSizeHint () );
    m_tabWidget->setMinimumSize( m_recorder->minimumSizeHint () );
    m_tabWidget->resize( m_tabWidget->minimumSizeHint () );
    m_splitter->setMinimumSize( QSize( 600, m_tabWidget->height() ) );
    m_splitter->resize( m_splitter->minimumSizeHint () );
    setMinimumSize( m_splitter->minimumSizeHint () );
    resize( minimumSizeHint () );

    connect(m_channellist, SIGNAL(signalStationChanged()),
            this,   SLOT(stationChanged()));
    m_channellist->loadChannellist();
}

KalvaView::~KalvaView()
{

}

void KalvaView::settingsChanged()
{
    m_channellist->loadChannellist();
    emit signalChangeStatusbar( i18n("Settings changed") );
}

void KalvaView::stationChanged()
{
    QString station = m_channellist->station();
    QString channel = m_channellist->channel();
    QString frq= m_channellist->frq();
    m_recorder->stationChanged(station,channel,frq);
    m_player->stationChanged(station,channel,frq);
}

KalvaChannellist* KalvaView::channellist() const
{
   return m_channellist;
}

/* DCOP Interfaces */

QString KalvaView::DcopFuzzyStation( const QString & yourStation )
{
   return m_channellist->yourFuzzyStation( yourStation );
}

ASYNC KalvaView::DcopPlay(
                const QString & yourStation
                )
{
   m_channellist->setStation( yourStation );
   m_player->play();
   m_tabWidget->setCurrentPage(0);
}

QString KalvaView::DcopRecordNow(
                const QString & yourStation,
                const QString & yourTitel,
                const QString & yourLength
                )
{
   m_channellist->setStation( yourStation );
   m_tabWidget->setCurrentPage(1);
   m_recorder->recordNow( yourTitel, yourLength );
   return i18n("recording immediatly");
}

QString KalvaView::DcopRecordMovie(
                const QString & yourStation,
                const QString & yourTitel,
                const QString & yourLength,
                const QString & yourStartTime,
                const QString & yourStartDate
                )
{
   m_channellist->setStation( yourStation );
   m_tabWidget->setCurrentPage(1);
   m_recorder->recordMovie( yourTitel, yourLength, yourStartTime, yourStartDate );
   return i18n("recording Movie");
}

QString KalvaView::DcopRecordSerial(
                const QString & yourStation,
                const QString & yourTitel,
                const QString & yourLength,
                const QString & yourStartTime,
                const QString & yourDOWs
                )
{
   m_channellist->setStation( yourStation );
   m_tabWidget->setCurrentPage(1);
   m_recorder->recordSerial( yourTitel, yourLength, yourStartTime, yourDOWs );
   return i18n("Recording serial");
}

#include "kalvaview.moc"
